@@ -13,6 +13,7 @@ use SQL::Entity ':all';
 @EXPORT_OK = qw(
     sql_relationship
     sql_column
+    sql_lob
     sql_index
     sql_cond
     sql_and
@@ -22,7 +23,7 @@ use SQL::Entity ':all';
 
 %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-$VERSION = 0.02;
+$VERSION = 0.03;
 
 =head1 NAME
 
@@ -69,6 +70,22 @@ Persistence::Entity - Persistence API for perl classes.
 
    $entity_manager->add_entities($membership_entity, $user_entity);
 
+LOB's support
+
+    my $photo_entity = Persistence::Entity->new(
+        name    => 'photo',
+        alias   => 'ph',
+        primary_key => ['id'],
+        columns => [
+            sql_column(name => 'id'),
+            sql_column(name => 'name', unique => 1),
+        ],
+        lobs => [
+            sql_lob(name => 'blob_content', size_column => 'doc_size'),
+        ]
+    );
+
+
 =head1 DESCRIPTION
 
 This class represents database entity.
@@ -77,6 +94,7 @@ This class represents database entity.
 
   sql_relationship
   sql_column
+  sql_lob
   sql_index
   sql_cond
   sql_and
@@ -286,7 +304,6 @@ sub relationship_query {
 Inserts the entity row
 Takes list of field values.
 
-
     $entity->insert(col1 => 'val1', col2 => 'val2');
 
 
@@ -297,6 +314,7 @@ sub insert {
     $self->_autogenerated_values(\%fields_values);
     my ($sql, $bind_variables) = $self->SUPER::insert(%fields_values, $self->dml_filter_values);
     $self->_execute_statement($sql, $bind_variables, "insert", \%fields_values);
+    $self->_update_lobs(\%fields_values);
     \%fields_values;
 }
 
@@ -333,13 +351,17 @@ Takes field values as hash ref, condition values as hash reference.
 
     $entity->update({col1 => 'val1', col2 => 'val2'}, {the_rowid => 'xx'});
 
+    my $lob = _load_file('t/bin/data1.bin');
+   $photo_entity->insert(id => "1", name => "photo1", blob_content => $lob);
+
 
 =cut
 
 sub update {
     my ($self, $fields_values, $condition_values) = @_;
     my ($sql, $bind_variables) = $self->SUPER::update({%$fields_values, $self->dml_filter_values}, $condition_values);
-    $self->_execute_statement($sql, $bind_variables, "update", $fields_values);
+    $self->_execute_statement($sql, $bind_variables, "update", $fields_values) if $sql;
+    $self->_update_lobs($fields_values, $condition_values);
 }
 
 
@@ -442,14 +464,16 @@ in case they are not contain primary key values.
 sub primary_key_values {
     my ($self, $dataset, $validate) = @_;
     my $result;
+    my @primary_key = $self->primary_key;
     if(! $self->has_primary_key_values($dataset)) {
         #only if has pk or unique values
         my $unique_values = $self->unique_condition_values($dataset);
         $result = $self->retrive_primary_key_values($unique_values) if (%$unique_values);
-        
+        if ($result) {
+            $result = {map { $_ => $result->{$_}} @primary_key};
+        }
 
     } else {
-        my @primary_key = $self->primary_key;
         $result = {map { $_ => $dataset->{$_}} @primary_key};
     }
     confess "cant retrive " .$self->name . "'s primary key values ["
@@ -476,6 +500,28 @@ sub has_primary_key_values {
 }
 
 
+=item fetch_lob
+
+Fetchs LOBs value.
+Takes lob column name, condition values.
+
+    my $blob = $photo_entity->fetch_lob('blob_content', {id => 10});
+
+=cut
+
+sub fetch_lob {
+    my ($self, $column,  $condition_values) = @_;
+    my $entity_manager = $self->entity_manager;
+    if(ref($condition_values) ne 'HASH') {
+        my $orm = $entity_manager->find_entity_mappings($condition_values);
+    }
+    my $pk_values = $self->primary_key_values($condition_values, 1);
+    my $lob = $self->lob($column);
+    my $connection = $self->entity_manager->connection;
+    $connection->fetch_lob($self->name, $lob->name, $pk_values, $lob->size_column);
+
+}
+
 =back
 
 =head2 PRIVATE METHODS
@@ -528,6 +574,40 @@ The following trigger types are supported: before_insert, after_insert, before_u
 }
 
 
+=item _update_lobs
+
+Updates LOB value.
+
+    $entity->_update_lobs({name => "photo1", blob_content => $bin_data}, {id => 1,});
+
+=cut
+
+sub _update_lobs {
+    my ($self, $fields_values, $condition_values) = @_;
+    $condition_values ||= $fields_values;
+    my $lobs = $self->_extract_lob_values($fields_values);
+    return if (! $lobs || ! %$lobs);
+    my $connection = $self->entity_manager->connection;
+    my $primary_key_values = $self->primary_key_values($condition_values, 1);
+    for my $k (keys %$lobs) {
+        my $lob = $self->lob($k);
+        $connection->update_lob($self->name, $lob->name, $lobs->{$k}, $primary_key_values, $lob->size_column);
+    }
+}
+
+
+=item _extract_lob_values
+
+=cut
+
+sub _extract_lob_values {
+    my ($self, $fields_values) = @_;
+    my $lobs = $self->lobs;
+    my $result = {map {($_ => $fields_values->{$_})} keys %$lobs};
+    wantarray ? @$result : $result;
+}
+
+
 =item _autogenerated_values
 
 Adds autogenerated values. Takes hash ref to field values
